@@ -1,4 +1,4 @@
-//@line 38 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-x86-nightly/build/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -53,7 +53,7 @@ var InlineSpellCheckerUI = {
     if (spellsel.rangeCount == 0)
       return; // easy case - no misspellings
 
-    var range = this.mInlineSpellChecker.getMispelledWord(rangeParent,
+    var range = this.mInlineSpellChecker.getMisspelledWord(rangeParent,
                                                           rangeOffset);
     if (! range)
       return; // not over a misspelled word
@@ -186,7 +186,6 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
-      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
