@@ -59,9 +59,9 @@ pref("general.warnOnAboutConfig", true);
 pref("browser.bookmarks.max_backups",       5);
 
 pref("browser.cache.disk.enable",           true);
-//@line 63 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 63 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         51200);
-//@line 67 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 67 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("browser.cache.memory.enable",         true);
 //pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
@@ -70,7 +70,7 @@ pref("browser.cache.disk_cache_ssl",        false);
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 76 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 76 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -81,7 +81,7 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 92 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 92 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
@@ -145,11 +145,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 156 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 156 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 159 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 159 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 161 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 161 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -167,7 +167,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 179 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 179 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -180,7 +180,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 195 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 195 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -524,9 +524,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 539 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 539 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 541 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 541 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -575,7 +575,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 592 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 592 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -813,7 +813,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 835 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 835 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -841,9 +841,7 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 864 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 871 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1194,6 +1192,12 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
+// How long a plugin is allowed to process a synchronous IPC message
+// before we consider it "hung".
+//
+//  NB: chosen to match dom.max_script_run_time by default
+pref("dom.ipc.plugins.timeoutSecs", 10);
+
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
 
@@ -1229,15 +1233,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1654 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 1652 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2078 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2076 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2281 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2279 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2377 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2375 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2380 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2378 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1507,20 +1511,20 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2652 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2650 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2720 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2718 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2746 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2744 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2766 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2764 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2768 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2766 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2774 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2772 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1557,12 +1561,15 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2816 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2814 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2821 "/export/home/ffslavex/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
+//@line 2819 "/export/home/moz/tools/ff_slave/mozilla-1.9.2-solaris-x86-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
+// Enable/Disable the orientation API for content
+pref("accelerometer.enabled", true);
+
 // Enable/Disable HTML5 parser
 pref("html5.enable", false);
